1.38.0[−][src]Macro frame_support::dispatch::fmt::Debug
macro_rules! Debug { ($item:item) => { ... }; }
Derive macro generating an impl of the trait Debug.
macro_rules! Debug { ($item:item) => { ... }; }
Derive macro generating an impl of the trait Debug.