1.2.0[−][src]Struct frame_support::dispatch::fmt::DebugList
A struct to help with fmt::Debug implementations.
This is useful when you wish to output a formatted list of items as a part
of your Debug::fmt implementation.
This can be constructed by the
Formatter::debug_list
method.
Examples
use std::fmt; struct Foo(Vec<i32>); impl fmt::Debug for Foo { fn fmt(&self, fmt: &mut fmt::Formatter) -> fmt::Result { fmt.debug_list().entries(self.0.iter()).finish() } } assert_eq!( format!("{:?}", Foo(vec![10, 11])), "[10, 11]", );
Implementations
impl<'a, 'b> DebugList<'a, 'b> where
'b: 'a, [src][−]
'b: 'a,
pub fn entry(&mut self, entry: &dyn Debug) -> &mut DebugList<'a, 'b>[src][−]
Adds a new entry to the list output.
Examples
use std::fmt; struct Foo(Vec<i32>, Vec<u32>); impl fmt::Debug for Foo { fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result { fmt.debug_list() .entry(&self.0) // We add the first "entry". .entry(&self.1) // We add the second "entry". .finish() } } assert_eq!( format!("{:?}", Foo(vec![10, 11], vec![12, 13])), "[[10, 11], [12, 13]]", );
pub fn entries<D, I>(&mut self, entries: I) -> &mut DebugList<'a, 'b> where
D: Debug,
I: IntoIterator<Item = D>, [src][−]
D: Debug,
I: IntoIterator<Item = D>,
Adds the contents of an iterator of entries to the list output.
Examples
use std::fmt; struct Foo(Vec<i32>, Vec<u32>); impl fmt::Debug for Foo { fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result { fmt.debug_list() .entries(self.0.iter()) .entries(self.1.iter()) .finish() } } assert_eq!( format!("{:?}", Foo(vec![10, 11], vec![12, 13])), "[10, 11, 12, 13]", );
pub fn finish(&mut self) -> Result<(), Error>[src][−]
Finishes output and returns any error encountered.
Examples
use std::fmt; struct Foo(Vec<i32>); impl fmt::Debug for Foo { fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result { fmt.debug_list() .entries(self.0.iter()) .finish() // Ends the struct formatting. } } assert_eq!( format!("{:?}", Foo(vec![10, 11])), "[10, 11]", );